<?php

// +---------------------------------------------------------------------------+
// | Import 1.0 for Geeklog - The Ultimate Weblog                              |
// +---------------------------------------------------------------------------+
// | import.php                                                                |
// |                                                                           |
// | This file is the import utility for Geeklog. Simply drop this file into   |
// | your admin directory and open it to import text and html files into your  |
// | geeklog database as a story.                                              |
// +---------------------------------------------------------------------------+
// | Copyright (C) 2002 by the following authors:                              |
// |                                                                           |
// | Authors: Tom Willett        - tomw@pigstye.net                            |
// +---------------------------------------------------------------------------+
// |                                                                           |
// | This program is free software; you can redistribute it and/or             |
// | modify it under the terms of the GNU General Public License               |
// | as published by the Free Software Foundation; either version 2            |
// | of the License, or (at your option) any later version.                    |
// |                                                                           |
// | This program is distributed in the hope that it will be useful,           |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
// | GNU General Public License for more details.                              |
// |                                                                           |
// | You should have received a copy of the GNU General Public License         |
// | along with this program; if not, write to the Free Software Foundation,   |
// | Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.           |
// |                                                                           |
// +---------------------------------------------------------------------------+
//

//
// you will need to edit the path to lib-common.php if you put this file anywhere other than
// the admin directory in a standard install
//
require_once('../lib-common.php');

// Only let Root users access this page
if (!SEC_inGroup('Root')) {
    // Someone is trying to illegally access this page
    COM_errorLog("Someone has tried to illegally access the Import page.  User id: {$_USER['uid']}, Username: {$_USER['username']}, IP: $REMOTE_ADDR",1);
    $display = COM_siteHeader();
    $display .= COM_startBlock("Access Denied!!!");
    $display .= "You are illegally trying to access the Import Story page.  This attempt has been logged";
    $display .= COM_endBlock();
    $display .= COM_siteFooter(true);
    echo $display;
    exit;
}

/** 
* Saves story to database
* Taken from story.php
*
* @param    string      $type           ??
* @param    string      $sid            ID of story to save
* @param    int         $uid            ID of user that wrote the story
* @param    string      $tid            Topic ID story belongs to
* @param    string      $title          Title of story
* @param    string      $introtext      Introduction text
* @param    string      $bodytext       Text of body
* @param    int         $hits           Number of times story has been viewed
* @param    string      $unixdate       Date story was originally saved
* @param    int         $comments       Number of user comments made to this story
* @param    int         $featured       Flag on whether or not this is a featured article
* @param    string      $commentcode    Indicates if comments are allowed to be made to article
* @param    string      $statuscode     Status of the story
* @param    string      $postmode       Is this HTML or plain text?
* @param    string      $frontpage      Flag indicates if story will appear on front page and topic or just topic
* @param    int         $draft_flag     Flag indicates if story is a draft or not
* @param    int         $numemails      Number of times this story has been emailed to someone
* @param    int         $owner_id       ID of owner (not necessarily the author)
* @param    int         $group_id       ID of group story belongs to
* @param    int         $perm_owner     Permissions the owner has on story
* @param    int         $perm_group     Permissions the group has on story
* @param    int         $perm_member    Permissions members have on story
* @param    int         $perm_anon      Permissions anonymous users have on story
* @param    int         $delete         String array of attached images to delete from article
*
*/
function submitstory($type='',$sid,$uid,$tid,$title,$introtext,$bodytext,$hits,$unixdate,$comments,$featured,$commentcode,$statuscode,$postmode,$frontpage,$draft_flag,$numemails,$owner_id,$group_id,$perm_owner,$perm_group,$perm_members,$perm_anon,$delete,$show_topic_icon) 
{
    global $_TABLES, $_CONF, $LANG24, $HTTP_POST_FILES;
        
    if (!empty($title) && !empty($introtext)) {
        $date = date("Y-m-d H:i:s",$unixdate);
        
        if (empty($hits)) {
            $hits = 0;
        }

        // Get draft flag value
        if ($draft_flag == 'on') {
            $draft_flag = 1;
        } else {
            $draft_flag = 0;
        }

        // Convert array values to numeric permission values
        list($perm_owner,$perm_group,$perm_members,$perm_anon) = SEC_getPermissionValues($perm_owner,$perm_group,$perm_members,$perm_anon);

        if ($featured == '1') {
            // there can only be one non-draft featured story
            if ($draft_flag == 0 AND $unixdate <= time()) {
                $id[1] = 'featured';
                $values[1] = 1;
                $id[2] = 'draft_flag';
                $values[2] = 0;
                DB_change($_TABLES['stories'],'featured','0',$id,$values);
            }

            // if set to featured force to show on front page
            $frontpage = 1;
        }

        if (empty($numemails)) {
            $numemails = 0;
        }
        
        if ($show_topic_icon == 'on') {
            $show_topic_icon = 1;
        } else {
            $show_topic_icon = 0;
        }
        
        // Get the related URLs
        $fulltext = "$introtext $bodytext";
        $check = " ";
        while($check != $reg[0]) {
            $check = $reg[0];

            // this gets any links from the article
            eregi("<a([^<]|(<[^/])|(</[^a])|(</a[^>]))*</a>",$fulltext,$reg);

            // this gets what is between <a href=...> and </a>
            preg_match("/<a href=([^\]]+)>([^\]]+)<\/a>/",stripslashes($reg[0]),$url_text);
            if (empty($url_text[1])) {
                preg_match("/<A HREF=([^\]]+)>([^\]]+)<\/A>/",stripslashes($reg[0]),$url_text);
            }
			
            $orig = $reg[0]; 

            //if links is too long, shorten it and add ... at the end
            if (strlen($url_text[2]) > 26) {
                $new_text = substr($url_text[2],0,26) . '...';
                // NOTE, this assumes there is no space between > and url_text[1]
                $reg[0] = str_replace(">".$url_text[2],">".$new_text,$reg[0]);
            }	

            if(stristr($fulltext,"<img ")) {
                // this is a linked images tag, ignore
                $reg[0] = '';
            }

            if ($reg[0] != '') {
                $fulltext = str_replace($orig,'',$fulltext);
            }

            if ($check != $reg[0]) {
                // Only write if we are dealing with something other than an image 
                if(!(stristr($reg[0],"<img "))) { 
                    $related .= "<li>" . stripslashes($reg[0]);
                }
            }
        }

        $author = DB_getItem($_TABLES['users'],'username',"uid = $uid");
        $topic = DB_getItem($_TABLES['topics'],'topic',"tid = '$tid'");

        if ($_CONF["contributedbyline"] == 1) {
            $related .= "<li><a href=\"{$_CONF['site_url']}/search.php?mode=search&amp;type=stories&amp;author=$uid\">{$LANG24[37]} $author</a>\n";
        }

        $related .= "<li><a href=\"{$_CONF['site_url']}/search.php?mode=search&amp;type=stories&amp;topic=$tid\">{$LANG24[38]} $topic</a>\n";
        $related = addslashes(COM_checkHTML(COM_checkWords($related)));

        // Clean up the text
        $introtext = addslashes($introtext);
        $bodytext = addslashes($bodytext);
        
        $title = addslashes(htmlspecialchars(strip_tags(COM_checkWords($title))));
        $comments = DB_count($_TABLES['comments'],'sid',$sid);

        
        DB_save($_TABLES['stories'],'sid,uid,tid,title,introtext,bodytext,hits,date,comments,related,featured,commentcode,statuscode,postmode,frontpage,draft_flag,numemails,owner_id,group_id,perm_owner,perm_group,perm_members,perm_anon,show_topic_icon',"$sid,$uid,'$tid','$title','$introtext','$bodytext',$hits,'$date','$comments','$related',$featured,'$commentcode','$statuscode','$postmode','$frontpage',$draft_flag,$numemails,$owner_id,$group_id,$perm_owner,$perm_group,$perm_members,$perm_anon,$show_topic_icon", $_CONF['site_admin_url'] . '/story.php?msg=9');
        
    } else {
        $display .= COM_siteHeader('menu');
        $display .= COM_errorLog($LANG24[31],2);
        $display .= COM_siteFooter();
        echo $display;
        exit;
    }
}

/*
* Main Function
*/

if ($import == 'Import File') {
    $buffer='';
    $fd = fopen($impfile,'r');
    com_errorlog("filesize of $impfile is " . filesize($impfile),1);
    $buffer = fread ($fd, filesize ($impfile));
    fclose($fd);
    if ($body == 'on') {
        $buffer = substr($buffer,strpos(strtolower($buffer),'<body'));
        $buffer = substr($buffer,strpos($buffer,'>')+1);
        $buflen = strpos(strtolower($buffer),'</body');
        if ($buflen > 0) {
            $buffer = substr($buffer,0,$buflen);
        }
    }
    if ($filter == 'on') {
        $buffer=COM_checkHTML(COM_checkWords($buffer));
    }
    if ($postmode == 'plaintext') {
        $buffer=htmlspecialchars(COM_checkWords($buffer));
    }
    submitstory('',COM_makesid(),$owner_id,$topic_id,$title,$introtext,$buffer,0,time(),0,$featured,$commentcode,$statuscode,$postmode,$frontpage,$draft,0,$owner_id,$group_id,$perm_owner,$perm_group,$perm_members,$perm_anon,'',$topic_icon);
}
$display = COM_siteHeader();
$display .= COM_startBlock("Import -- Import files into Geeklog Database As Articles");
$display .= "<p>This Page imports a standard html page into Geeklog as a Story. If the 'Body' option is checked, it looks first ";
$display .= "for the &ltbody&gt tag.  It includes everything after the &ltbody&gt tag until it";
$display .= " finds the &lt/body&gt tag.  If there is script in the &lthead&gt tag it is ignored.";
$display .= " If the 'Filter HTML' option is checked it filters the file according to Geeklogs default ";
$display .= "filter, otherwise all html is allowed.</p>";
$display .= "<form method=\"post\" action=\"{$_CONF['site_admin_url']}/import.php\" enctype=\"multipart/form-data\">";
$display .= "<input type=\"hidden\" name=\"MAX_FILE_SIZE\" value=\"1000000\">";
$display .= "File:&nbsp;&nbsp;&nbsp;<input type=\"file\" name=\"impfile\" size=\"40\"><p>";
$display .= 'Only Body&nbsp;&nbsp;<input type="checkbox" name="body" value="on" checked>';
$display .= '&nbsp;&nbspFilter HTML&nbsp;&nbsp;<input type="checkbox" name="filter" value="on" checked>';
$display .= '&nbsp;&nbsp;Import Type&nbsp;&nbsp;<select name="postmode"><option value="html" selected>HTML</option><option value="plaintext">Text Only</option></select><p>';
$display .= "Title:&nbsp;&nbsp;&nbsp;<input type=\"text\" name=\"title\" size=\"40\"><br>";
$display .= 'Topic:&nbsp;&nbsp;<SELECT name="topic_id">' . COM_optionList($_TABLES['topics'],"tid,topic",'') . "</SELECT>";
$display .= '&nbsp;&nbsp;Show Topic Icon&nbsp;&nbsp;<input type="checkbox" name="topic_icon" value="on" checked>';
$display .= '&nbsp;&nbsp;Draft&nbsp;&nbsp;<input type="checkbox" name="draft" value="on">';
$display .= '<br>Mode:&nbsp&nbsp<select name="statuscode"><option value="10">Archive</option>';
$display .= '<option value="0" selected>Normal</option><option value="1">Refreshing</option></select>';
$display .= '<select name="commentcode"><option value="-1">Comments Disabled</option>';
$display .= '<option value="0" selected>Comments Enabled</option></select>';
$display .= '<select name="featured"><option value="1">Featured</option>';
$display .= '<option value="0" selected>Not Featured</option></select>';
$display .= '<select name="frontpage"><option value="1" selected>Show on Front Page</option>';
$display .= '<option value="0">Show Only in Topic</option></select><br>';
$display .= 'Intro Text: &nbsp;&nbsp;<textarea name="introtext" cols="50" rows="6" wrap="virtual"></textarea>';
$display .= "<hr>Owner&nbsp;&nbsp;&nbsp;";
$display .= '<SELECT name="owner_id">' . COM_optionList($_TABLES['users'],"uid,username",$_USER['uid']) . "</SELECT>";
$display .= "<br>Group&nbsp;&nbsp;&nbsp;";
$display .= '<SELECT name="group_id">' . COM_optionList($_TABLES['groups'],"grp_id,grp_name",'1')  . "</SELECT>";
$display .= '<br>Permissions:';
$display .= SEC_getPermissionsHTML(3,3,2,2);
$display .= "<p><input type=\"submit\" name=\"import\" value=\"Import File\"></p>";
$display .= "</form>";
$display .= COM_endBlock();
$display .= COM_siteFooter(false);
echo $display;
?>